@@ -1,4 +1,5 @@
-from pydoctest.configuration import Configuration, Verbosity
+from typing import Optional
+from pydoctest.configuration import Verbosity
 from pydoctest.reporters.reporter import Reporter
 from pydoctest.validation import ClassValidationResult, FunctionValidationResult, ModuleValidationResult, ResultType, ValidationResult
 
@@ -45,25 +46,33 @@ class TextReporter(Reporter):
 
         return output
 
-    def get_function_output(self, result: FunctionValidationResult) -> str:
+    def get_function_output(self, result: FunctionValidationResult, class_name: Optional[str] = None) -> str:
         """Returns the text output from the result object from the function.
 
         Args:
             result (FunctionValidationResult): The result from running Pydoctest on the function.
-
+            class_name (Optional[str]): Optionally which class this function is run within.
         Returns:
             str: The output from the function.
         """
+        result.module.__file__
+        try:
+            # Try to get just workspace relative path
+            module = result.module.__file__.replace(self.config.working_directory, "")
+        except Exception:
+            pass
+        function_name = result.function.__name__
+        class_name_if_exists = class_name + '::' if class_name is not None else ''
         if result.result == ResultType.OK:
             if self.config.verbosity == Verbosity.SHOW_ALL:
-                return f"Function: {result.function} {SUCCESS}\n"
+                return f"{module}::{class_name_if_exists}{function_name} {SUCCESS}\n"
             return ""
 
         if result.result == ResultType.FAILED:
-            return f"Function: {result.function} {FAILED} | {result.fail_reason}\n"
+            return f"{module}::{class_name_if_exists}{function_name} {FAILED} | {result.fail_reason}\n"
 
         if result.result == ResultType.NO_DOC and self.config.fail_on_missing_docstring:
-            return f"Function: {result.function} is missing a docstring\n"
+            return f"{module}::{class_name_if_exists}{function_name} is missing a docstring\n"
 
         return ""
 
@@ -78,5 +87,5 @@ class TextReporter(Reporter):
         """
         output = ""
         for fn in result.function_results:
-            output += self.get_function_output(fn)
+            output += self.get_function_output(fn, class_name=result.class_name)
         return output
